@@ -10,7 +10,6 @@ import (
 	contents "github.com/Equationzhao/g/internal/content"
 	"github.com/Equationzhao/g/internal/display"
 	"github.com/Equationzhao/g/internal/filter"
-	"github.com/Equationzhao/g/internal/timeparse"
 	"github.com/gabriel-vasile/mimetype"
 	"github.com/urfave/cli/v2"
 )
@@ -169,7 +168,7 @@ var viewFlag = []cli.Flag{
 		Usage: `time/date format with -l, 
 	valid timestamp styles are default, iso, long-iso, full-iso, locale, 
 	custom +FORMAT like date(1). 
-	(default: +%d.%b'%y %H:%M ,like 02.Jan'06 15:04)`,
+	(default: +%b %d %H:%M ,like Jan 02 15:04)`,
 		EnvVars: []string{"TIME_STYLE"},
 		Action: func(context *cli.Context, s string) error {
 			_ = context.Set("time", "1")
@@ -179,8 +178,7 @@ var viewFlag = []cli.Flag{
 				Also, the TIME_STYLE environment variable sets the default style to use.
 			*/
 			if strings.HasPrefix(s, "+") {
-				s := s[1:] // remove +
-				timeFormat = timeparse.Transform(s)
+				timeFormat = s
 				return nil
 			}
 
@@ -194,7 +192,7 @@ var viewFlag = []cli.Flag{
 			case "iso":
 				timeFormat = "01-02 15:04"
 			case "default":
-				timeFormat = "02.Jan'06 15:04"
+				timeFormat = "Jan 02 15:04"
 			default:
 				ReturnCode = 2
 				return errors.New("invalid time-style")
@@ -598,6 +596,12 @@ var viewFlag = []cli.Flag{
 		DisableDefaultText: true,
 		Category:           "VIEW",
 	},
+	&cli.BoolFlag{
+		Name:               "git-detail",
+		Usage:              "show git commit detail with hash, author, author date [if git is installed]",
+		DisableDefaultText: true,
+		Category:           "VIEW",
+	},
 	&cli.BoolFlag{
 		Name:               "git-repo-branch",
 		Usage:              "list root of git-tree branch [if git is installed]",
