@@ -171,10 +171,34 @@ var Ext = Theme{
 		Color: pkg,
 		Icon:  "\uF306",
 	},
+	"aab": Style{
+		Color: global.Green,
+		Icon:  "\uF17B",
+	},
+	"aar": Style{
+		Color: global.Green,
+		Icon:  "\uF17B",
+	},
 	"apk": Style{
 		Color: global.Green,
 		Icon:  "\uF17B",
 	},
+	"dex": Style{
+		Color: global.Green,
+		Icon:  "\uF17B",
+	},
+	"odex": Style{
+		Color: global.Green,
+		Icon:  "\uF17B",
+	},
+	"aidl": Style{
+		Color: lang,
+		Icon:  "\uF17B",
+	},
+	"hidl": Style{
+		Color: lang,
+		Icon:  "\uF17B",
+	},
 	"app": Style{
 		Color: global.Green,
 		Icon:  "\ueb44",
@@ -279,6 +303,10 @@ var Ext = Theme{
 		Color: lang,
 		Icon:  "\uE755",
 	},
+	"xcplayground": Style{
+		Color: lang,
+		Icon:  "\uE755",
+	},
 	"kt": Style{
 		Color: lang,
 		Icon:  "\uE634",
@@ -313,7 +341,7 @@ var Ext = Theme{
 	},
 	"astro": Style{
 		Color: lang,
-		Icon:  "\\uf135",
+		Icon:  "\uf135",
 	},
 	"js": Style{
 		Color: lang,
@@ -1672,6 +1700,15 @@ var Git = map[string]Style{
 		Color: global.BrightBlack,
 		Icon:  "-",
 	},
+	"git-author": {
+		Color: rgb(67, 202, 207),
+	},
+	"git-author-date": {
+		Color: rgb(54, 102, 180),
+	},
+	"git-commit-hash": {
+		Color: global.BrightBlack,
+	},
 }
 
 var Owner = map[string]Style{
