@@ -3,15 +3,12 @@ package util
 import (
 	"fmt"
 	"io/fs"
-	"math/rand/v2"
 	"os"
 	"path/filepath"
 	"time"
 
-	"github.com/Equationzhao/g/internal/global"
 	"github.com/Equationzhao/g/internal/item"
 	"github.com/Equationzhao/g/internal/osbased"
-	"github.com/spf13/afero"
 )
 
 func Evallinks(fullPath string) (string, error) {
@@ -48,70 +45,42 @@ func IsExecutableMode(mode os.FileMode) bool {
 	return mode&0o111 != 0
 }
 
-func GenRandomData(n int) []byte {
-	const (
-		letterIdxBits = 6
-		letterIdxMask = 1<<letterIdxBits - 1
-		letterIdxMax  = 63 / letterIdxBits
-	)
-	set := []byte{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'}
-	b := make([]byte, n)
-	for i, cache, remain := n-1, rand.Int64(), letterIdxMax; i >= 0; {
-		if remain == 0 {
-			cache, remain = rand.Int64(), letterIdxMax
-		}
-		if idx := int(cache & letterIdxMask); idx < len(set) {
-			b[i] = set[idx]
-			i--
-		}
-		cache >>= letterIdxBits
-		remain--
-	}
-	return b
-}
-
 // RecursivelySizeOf returns the size of the file or directory
 // depth < 0 means no limit
 func RecursivelySizeOf(info *item.FileInfo, depth int) int64 {
-	return RecursivelySizeOfGenerator(global.Fs)(info, depth)
-}
-
-func RecursivelySizeOfGenerator(afs afero.Fs) func(info *item.FileInfo, depth int) int64 {
-	return func(info *item.FileInfo, depth int) int64 {
-		currentDepth := 0
-		if info.IsDir() {
-			totalSize := int64(0)
-			if depth < 0 {
-				// -1 means no limit
-				_ = afero.Walk(afs, info.FullPath, func(path string, dir fs.FileInfo, err error) error {
-					if err != nil {
-						return err
-					}
-					totalSize += dir.Size()
-					return nil
-				})
-			} else {
-				_ = afero.Walk(afs, info.FullPath, func(path string, dir fs.FileInfo, err error) error {
-					if err != nil {
-						return err
-					}
-					if currentDepth > depth {
-						if dir.IsDir() {
-							return filepath.SkipDir
-						}
-						return nil
-					}
-					totalSize += dir.Size()
+	currentDepth := 0
+	if info.IsDir() {
+		totalSize := int64(0)
+		if depth < 0 {
+			// -1 means no limit
+			_ = filepath.Walk(info.FullPath, func(path string, dir fs.FileInfo, err error) error {
+				if err != nil {
+					return err
+				}
+				totalSize += dir.Size()
+				return nil
+			})
+		} else {
+			_ = filepath.Walk(info.FullPath, func(path string, dir fs.FileInfo, err error) error {
+				if err != nil {
+					return err
+				}
+				if currentDepth > depth {
 					if dir.IsDir() {
-						currentDepth++
+						return filepath.SkipDir
 					}
 					return nil
-				})
-			}
-			return totalSize
+				}
+				totalSize += dir.Size()
+				if dir.IsDir() {
+					currentDepth++
+				}
+				return nil
+			})
 		}
-		return info.Size()
+		return totalSize
 	}
+	return info.Size()
 }
 
 type MockFileInfo struct {
